<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * AZONSearchBox starts here. Manager sets mode, adds required wp hooks and loads required object of structure
 *
 * Manager controls and access to all modules and classes of AZONSearchBox.
 *
 * @package AZONSearchBox
 * @since   1.0
 */
class AZON_Search_Box {

	/**
	 * Constructor loads API functions, defines paths and adds required wp actions
	 *
	 * @since  1.0
	 */
	public function __construct() 
	{
		add_action( 'init', array( $this, 'init' ), 9 );
	}

	/**
	 * Callback function for WP init action hook. Sets AZONSearchBox mode and loads required objects.
	 *
	 * @since  1.0
	 * @access public
	 *
	 * @return void
	 */
	public function init() 
	{
		do_action( 'AZONSearchBox_before_init' );
		
		global $wpdb;
		$this->db = $wpdb;

		if( is_admin() ){
			$this->editor_assets();
		}
		else{
			$this->frontend_assets();
		}

		do_action( 'AZONSearchBox_after_init' );
	}

	public function frontend_assets()
	{
		wp_enqueue_style(
			'azon-searchbox/view-style',
			plugins_url( 'frontend/frontend.view.css', __FILE__ ),
			array( 'wp-edit-blocks' )
		);

		wp_enqueue_style(
			'azon-searchbox/custom-font',
			plugins_url( '../assets/fonts/iconmoon.css', __FILE__ ),
			array( 'wp-edit-blocks' )
		);

		wp_enqueue_script(
			'azon-searchbox/view-script',
			plugins_url( 'frontend/frontend.build.js', __FILE__ ),
			array( 'wp-components' )
	  	);

	  	wp_localize_script( 'azon-searchbox/view-script', 'AZON', array(
			'assets_url' => AZON_BLOCK_URL,
			'google_fonts' => array()
		) );
	}

	public function editor_assets()
	{
		wp_enqueue_script(
			'azon-searchbox/editor',
			plugins_url( 'backend/backend.build.js', __FILE__ ),
			array( 'wp-blocks', 'wp-element', 'wp-editor' )
	  	);

	  	wp_enqueue_style(
			'azon-searchbox/custom-font',
			plugins_url( '../assets/fonts/iconmoon.css', __FILE__ ),
			array( 'wp-edit-blocks' )
		);

		wp_enqueue_style(
			'azon-searchbox/view-style',
			plugins_url( 'frontend/frontend.view.css', __FILE__ ),
			array( 'wp-edit-blocks' )
		);

		wp_enqueue_style(
			'azon-searchbox/editor',
			plugins_url( 'backend/backend.editor.css', __FILE__ ),
			array( 'wp-edit-blocks' )
		);

		wp_localize_script( 'azon-searchbox/editor', 'AZON', array(
			'ajax_url' => apply_filters( 'AZONSearchBox_ref', admin_url('admin-ajax.php?action=YVYAjaxRequest') ),
			'assets_url' => AZON_BLOCK_URL,
			'google_fonts' => array()
		) );

		wp_enqueue_script( 'jquery-ui-core' );
		wp_enqueue_script( 'jquery-ui-draggable' );
	}
}

/**
 * Main AZONSearchBox manager.
 * @var AZONSearchBox $AZONSearchBox - instance of composer management.
 * @since 1.0
 */
global $AZONSearchBox;
$AZONSearchBox = new AZON_Search_Box();

function AZONSearchBox(){
	global $AZONSearchBox;

	return $AZONSearchBox;
}